@@ -305,7 +305,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 
         if ms_drivers.match(driver) and os.name == 'nt':
             cstr_parts['MARS_Connection'] = 'yes'
-        print('cstr_parts--> ', cstr_parts)
+        # print('cstr_parts--> ', cstr_parts)
         connstr = encode_connection_string(cstr_parts)
         print('connection String--> ', connstr)
         # extra_params are glued on the end of the string without encoding,
@@ -325,10 +325,9 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         need_to_retry = False
         while conn is None:
             try:
-                conn = Database.connect(connstr,
-                                        unicode_results=unicode_results,
-                                        timeout=timeout)
+                conn = Database.connect(connstr)
             except Exception as e:
+                print('Error occurred during connect: ', e)
                 for error_number in self._transient_error_numbers:
                     if error_number in e.args[1]:
                         if error_number in e.args[1] and retry_count < retries:
